unit uDM1;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, sqlite3conn, sqldb, LazFileUtils, lazlogger, IDEWindowIntf,
  XMLPropStorage, IniPropStorage, Forms, AbZipper, AbZipKit, DCPsha1, LR_Class,
  LR_Desgn, LR_DBSet, LR_E_HTM, LR_E_TXT, LRDialogControls, LR_PQConnection;

type

  { TDM1 }

  TDM1 = class(TDataModule)
    AbZipKit1: TAbZipKit;
    AbZipper1: TAbZipper;
    Con1: TSQLite3Connection;
    DCP_sha1_1: TDCP_sha1;
    frDBDataSet1: TfrDBDataSet;
    frDBDataSet2: TfrDBDataSet;
    frDesigner1: TfrDesigner;
    frHTMExport1: TfrHTMExport;
    frReport1: TfrReport;
    frTextExport1: TfrTextExport;
    IDEDialogLayoutStorage1: TIDEDialogLayoutStorage;
    IniPropStorage1: TIniPropStorage;
    LRDialogControls1: TLRDialogControls;
    LR_PQConnection1: TLR_PQConnection;
    QMedikamente: TSQLQuery;
    QYear: TSQLQuery;
    QMonth: TSQLQuery;
    QDay: TSQLQuery;
    SQLTran1: TSQLTransaction;
    XMLPropStorage1: TXMLPropStorage;

    procedure DataModuleCreate(Sender: TObject);

  private
    function CreateDB: Boolean;
    function CreateTables: Boolean;
    function DeleteDB: Boolean;
    function GetDatabase: string;
    procedure SetDatabase(AValue: string);
    { private declarations }
  public
    { public declarations }
    function TestAndOpenDB:Boolean;
    property DatabaseName: string read GetDatabase write SetDatabase;
  end;

var
  DM1: TDM1;

implementation

{$R *.lfm}

procedure TDM1.SetDatabase(AValue: string);
begin
  if Con1.DatabaseName=AValue then Exit;
  Con1.DatabaseName:=AValue;
end;

function TDM1.GetDatabase: string;
begin
  Result := Con1.DatabaseName;
end;

procedure TDM1.DataModuleCreate(Sender: TObject);
begin
  Con1.Options:= [scoApplyUpdatesChecksRowsAffected];
end;

function TDM1.CreateDB: Boolean;
var
  DirStr: String;
begin
  Result := false;
  {Wenn wir bereits verbunden sind, dann können wir dei DB nicht erzeugen}
  if Con1.Connected then
  begin
    DebugLn('Error: Already connected to the DB');
    exit; //-->
  end;
  {Testen ob Directory existiert wenn nicht erstelle Directory}
  DirStr:= ExtractFileDir(Con1.DatabaseName);
  if not DirectoryExists(DirStr) then
  begin
     CreateDir(DirStr);
  end;
  {Testen ob die Datei bereits vorhanden ist}
  if FileExists(Con1.DatabaseName) then
  begin
    DebugLn('Error: DB already exists');
    exit; //-->
  end;
  Con1.CreateDB;
  DebugLn('CreateDB finished');
  Result := CreateTables;
end;

function TDM1.TestAndOpenDB: Boolean;
begin
  Result := false;
  if Con1.Connected then
  begin
    DebugLn('Hint: DB already open');
    Result := Con1.Connected;
    exit; //==>
  end;
  if not FileExists(Con1.DatabaseName) then
  begin
    DebugLn('Hint: Create DB now');
    if not CreateDB then
    begin
      Result := false;
      exit; //==>
    end;
    if not CreateTables then
    begin
      Result := false;
      exit; //==>
    end;
  end;
  if not Con1.Connected then
  begin
    Con1.Connected:=true;
  end;
  Result := Con1.Connected;
end;

function TDM1.CreateTables: Boolean;
var
  SQL: String;
begin
  Result := false;
  if not Con1.Connected then
  begin
    DebugLn('Warning: DB not connected, try to connect');
    Con1.Connected:=true;
  end;
  // Todo
  SQL := 'CREATE TABLE IF NOT EXISTS tblMedikamente ' +
         '(ID INTEGER Primary KEY, Medikament VARCHAR(5),Medikament_long VARCHAR(25), Image BLOB)';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblMedikamente');
  end;

  SQL := 'CREATE TABLE IF NOT EXISTS tblDateTime ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
         '"Printed" VARCHAR(15), "00.00" VARCHAR(10), "00.15" VARCHAR(25),'+
         '"00.30" VARCHAR(25),"00.45" VARCHAR(25),"01.00" VARCHAR(25),'+
         '"01.15" VARCHAR(25),"01.30" VARCHAR(25),"01.45" VARCHAR(25),'+
         '"02.00" VARCHAR(25),"02.15" VARCHAR(25),"02.30" VARCHAR(25),'+
         '"02.45" VARCHAR(25),"03.00" VARCHAR(25),"03.15" VARCHAR(25),'+
         '"03.30" VARCHAR(25),"03.45" VARCHAR(25),"04.00" VARCHAR(25),'+
         '"04.15" VARCHAR(25),"04.30" VARCHAR(25),"04.45" VARCHAR(25),'+
         '"05.00" VARCHAR(25),"05.15" VARCHAR(25),"05.30" VARCHAR(25),'+
         '"05.45" VARCHAR(25),"06.00" VARCHAR(25),"06.15" VARCHAR(25),'+
         '"06.30" VARCHAR(25),"06.45" VARCHAR(25),"07.00" VARCHAR(25),'+
         '"07.15" VARCHAR(25),"07.30" VARCHAR(25),"07.45" VARCHAR(25),'+
         '"08.00" VARCHAR(25),"08.15" VARCHAR(25),"08.30" VARCHAR(25),'+
         '"08.45" VARCHAR(25),"09.00" VARCHAR(25),"09.15" VARCHAR(25),'+
         '"09.30" VARCHAR(25),"09.45" VARCHAR(25),"10.00" VARCHAR(25),'+
         '"10.15" VARCHAR(25),"10.30" VARCHAR(25),"10.45" VARCHAR(25),'+
         '"11.00" VARCHAR(25),"11.15" VARCHAR(25),"11.30" VARCHAR(25),'+
         '"11.45" VARCHAR(25),"12.00" VARCHAR(25),"12.15" VARCHAR(25),'+
         '"12.30" VARCHAR(25),"12.45" VARCHAR(25),"13.00" VARCHAR(25),'+
         '"13.15" VARCHAR(25),"13.30" VARCHAR(25),"13.45" VARCHAR(25),'+
         '"14.00" VARCHAR(25),"14.15" VARCHAR(25),"14.30" VARCHAR(25),'+
         '"14.45" VARCHAR(25),"15.00" VARCHAR(25),"15.15" VARCHAR(25),'+
         '"15.30" VARCHAR(25),"15.45" VARCHAR(25),"16.00" VARCHAR(25),'+
         '"16.15" VARCHAR(25),"16.30" VARCHAR(25),"16.45" VARCHAR(25),'+
         '"17.00" VARCHAR(25),"17.15" VARCHAR(25),"17.30" VARCHAR(25),'+
         '"17.45" VARCHAR(25),"18.00" VARCHAR(25),"18.15" VARCHAR(25),'+
         '"18.30" VARCHAR(25),"18.45" VARCHAR(25),"19.00" VARCHAR(25),'+
         '"19.15" VARCHAR(25),"19.30" VARCHAR(25),"19.45" VARCHAR(25),'+
         '"20.00" VARCHAR(25),"20.15" VARCHAR(25),"20.30" VARCHAR(25),'+
         '"20.45" VARCHAR(25),"21.00" VARCHAR(25),"21.15" VARCHAR(25),'+
         '"21.30" VARCHAR(25),"21.45" VARCHAR(25),"22.00" VARCHAR(25),'+
         '"22.15" VARCHAR(25),"22.30" VARCHAR(25),"22.45" VARCHAR(25),'+
         '"23.00" VARCHAR(25),"23.15" VARCHAR(25),"23.30" VARCHAR(25),'+
         '"23.45" VARCHAR(25)'+

         '"00.00_AUSL" VARCHAR(10), "00.15_AUSL" VARCHAR(25),'+
         '"00.30_AUSL" VARCHAR(25),"00.45_AUSL" VARCHAR(25),"01.00_AUSL" VARCHAR(25),'+
         '"01.15_AUSL" VARCHAR(25),"01.30_AUSL" VARCHAR(25),"01.45_AUSL" VARCHAR(25),'+
         '"02.00_AUSL" VARCHAR(25),"02.15_AUSL" VARCHAR(25),"02.30_AUSL" VARCHAR(25),'+
         '"02.45_AUSL" VARCHAR(25),"03.00_AUSL" VARCHAR(25),"03.15_AUSL" VARCHAR(25),'+
         '"03.30_AUSL" VARCHAR(25),"03.45_AUSL" VARCHAR(25),"04.00_AUSL" VARCHAR(25),'+
         '"04.15_AUSL" VARCHAR(25),"04.30_AUSL" VARCHAR(25),"04.45_AUSL" VARCHAR(25),'+
         '"05.00_AUSL" VARCHAR(25),"05.15_AUSL" VARCHAR(25),"05.30_AUSL" VARCHAR(25),'+
         '"05.45_AUSL" VARCHAR(25),"06.00_AUSL" VARCHAR(25),"06.15_AUSL" VARCHAR(25),'+
         '"06.30_AUSL" VARCHAR(25),"06.45_AUSL" VARCHAR(25),"07.00_AUSL" VARCHAR(25),'+
         '"07.15_AUSL" VARCHAR(25),"07.30_AUSL" VARCHAR(25),"07.45_AUSL" VARCHAR(25),'+
         '"08.00_AUSL" VARCHAR(25),"08.15_AUSL" VARCHAR(25),"08.30_AUSL" VARCHAR(25),'+
         '"08.45_AUSL" VARCHAR(25),"09.00_AUSL" VARCHAR(25),"09.15_AUSL" VARCHAR(25),'+
         '"09.30_AUSL" VARCHAR(25),"09.45_AUSL" VARCHAR(25),"10.00_AUSL" VARCHAR(25),'+
         '"10.15_AUSL" VARCHAR(25),"10.30_AUSL" VARCHAR(25),"10.45_AUSL" VARCHAR(25),'+
         '"11.00_AUSL" VARCHAR(25),"11.15_AUSL" VARCHAR(25),"11.30_AUSL" VARCHAR(25),'+
         '"11.45_AUSL" VARCHAR(25),"12.00_AUSL" VARCHAR(25),"12.15_AUSL" VARCHAR(25),'+
         '"12.30_AUSL" VARCHAR(25),"12.45_AUSL" VARCHAR(25),"13.00_AUSL" VARCHAR(25),'+
         '"13.15_AUSL" VARCHAR(25),"13.30_AUSL" VARCHAR(25),"13.45_AUSL" VARCHAR(25),'+
         '"14.00_AUSL" VARCHAR(25),"14.15_AUSL" VARCHAR(25),"14.30_AUSL" VARCHAR(25),'+
         '"14.45_AUSL" VARCHAR(25),"15.00_AUSL" VARCHAR(25),"15.15_AUSL" VARCHAR(25),'+
         '"15.30_AUSL" VARCHAR(25),"15.45_AUSL" VARCHAR(25),"16.00_AUSL" VARCHAR(25),'+
         '"16.15_AUSL" VARCHAR(25),"16.30_AUSL" VARCHAR(25),"16.45_AUSL" VARCHAR(25),'+
         '"17.00_AUSL" VARCHAR(25),"17.15_AUSL" VARCHAR(25),"17.30_AUSL" VARCHAR(25),'+
         '"17.45_AUSL" VARCHAR(25),"18.00_AUSL" VARCHAR(25),"18.15_AUSL" VARCHAR(25),'+
         '"18.30_AUSL" VARCHAR(25),"18.45_AUSL" VARCHAR(25),"19.00_AUSL" VARCHAR(25),'+
         '"19.15_AUSL" VARCHAR(25),"19.30_AUSL" VARCHAR(25),"19.45_AUSL" VARCHAR(25),'+
         '"20.00_AUSL" VARCHAR(25),"20.15_AUSL" VARCHAR(25),"20.30_AUSL" VARCHAR(25),'+
         '"20.45_AUSL" VARCHAR(25),"21.00_AUSL" VARCHAR(25),"21.15_AUSL" VARCHAR(25),'+
         '"21.30_AUSL" VARCHAR(25),"21.45_AUSL" VARCHAR(25),"22.00_AUSL" VARCHAR(25),'+
         '"22.15_AUSL" VARCHAR(25),"22.30_AUSL" VARCHAR(25),"22.45_AUSL" VARCHAR(25),'+
         '"23.00_AUSL" VARCHAR(25),"23.15_AUSL" VARCHAR(25),"23.30_AUSL" VARCHAR(25),'+
         '"23.45_AUSL" VARCHAR(25)'+

'"00.00_SCHMORT" VARCHAR(10), "00.15_SCHMORT" VARCHAR(25),'+
         '"00.30_SCHMORT" VARCHAR(25),"00.45_SCHMORT" VARCHAR(25),"01.00_SCHMORT" VARCHAR(25),'+
         '"01.15_SCHMORT" VARCHAR(25),"01.30_SCHMORT" VARCHAR(25),"01.45_SCHMORT" VARCHAR(25),'+
         '"02.00_SCHMORT" VARCHAR(25),"02.15_SCHMORT" VARCHAR(25),"02.30_SCHMORT" VARCHAR(25),'+
         '"02.45_SCHMORT" VARCHAR(25),"03.00_SCHMORT" VARCHAR(25),"03.15_SCHMORT" VARCHAR(25),'+
         '"03.30_SCHMORT" VARCHAR(25),"03.45_SCHMORT" VARCHAR(25),"04.00_SCHMORT" VARCHAR(25),'+
         '"04.15_SCHMORT" VARCHAR(25),"04.30_SCHMORT" VARCHAR(25),"04.45_SCHMORT" VARCHAR(25),'+
         '"05.00_SCHMORT" VARCHAR(25),"05.15_SCHMORT" VARCHAR(25),"05.30_SCHMORT" VARCHAR(25),'+
         '"05.45_SCHMORT" VARCHAR(25),"06.00_SCHMORT" VARCHAR(25),"06.15_SCHMORT" VARCHAR(25),'+
         '"06.30_SCHMORT" VARCHAR(25),"06.45_SCHMORT" VARCHAR(25),"07.00_SCHMORT" VARCHAR(25),'+
         '"07.15_SCHMORT" VARCHAR(25),"07.30_SCHMORT" VARCHAR(25),"07.45_SCHMORT" VARCHAR(25),'+
         '"08.00_SCHMORT" VARCHAR(25),"08.15_SCHMORT" VARCHAR(25),"08.30_SCHMORT" VARCHAR(25),'+
         '"08.45_SCHMORT" VARCHAR(25),"09.00_SCHMORT" VARCHAR(25),"09.15_SCHMORT" VARCHAR(25),'+
         '"09.30_SCHMORT" VARCHAR(25),"09.45_SCHMORT" VARCHAR(25),"10.00_SCHMORT" VARCHAR(25),'+
         '"10.15_SCHMORT" VARCHAR(25),"10.30_SCHMORT" VARCHAR(25),"10.45_SCHMORT" VARCHAR(25),'+
         '"11.00_SCHMORT" VARCHAR(25),"11.15_SCHMORT" VARCHAR(25),"11.30_SCHMORT" VARCHAR(25),'+
         '"11.45_SCHMORT" VARCHAR(25),"12.00_SCHMORT" VARCHAR(25),"12.15_SCHMORT" VARCHAR(25),'+
         '"12.30_SCHMORT" VARCHAR(25),"12.45_SCHMORT" VARCHAR(25),"13.00_SCHMORT" VARCHAR(25),'+
         '"13.15_SCHMORT" VARCHAR(25),"13.30_SCHMORT" VARCHAR(25),"13.45_SCHMORT" VARCHAR(25),'+
         '"14.00_SCHMORT" VARCHAR(25),"14.15_SCHMORT" VARCHAR(25),"14.30_SCHMORT" VARCHAR(25),'+
         '"14.45_SCHMORT" VARCHAR(25),"15.00_SCHMORT" VARCHAR(25),"15.15_SCHMORT" VARCHAR(25),'+
         '"15.30_SCHMORT" VARCHAR(25),"15.45_SCHMORT" VARCHAR(25),"16.00_SCHMORT" VARCHAR(25),'+
         '"16.15_SCHMORT" VARCHAR(25),"16.30_SCHMORT" VARCHAR(25),"16.45_SCHMORT" VARCHAR(25),'+
         '"17.00_SCHMORT" VARCHAR(25),"17.15_SCHMORT" VARCHAR(25),"17.30_SCHMORT" VARCHAR(25),'+
         '"17.45_SCHMORT" VARCHAR(25),"18.00_SCHMORT" VARCHAR(25),"18.15_SCHMORT" VARCHAR(25),'+
         '"18.30_SCHMORT" VARCHAR(25),"18.45_SCHMORT" VARCHAR(25),"19.00_SCHMORT" VARCHAR(25),'+
         '"19.15_SCHMORT" VARCHAR(25),"19.30_SCHMORT" VARCHAR(25),"19.45_SCHMORT" VARCHAR(25),'+
         '"20.00_SCHMORT" VARCHAR(25),"20.15_SCHMORT" VARCHAR(25),"20.30_SCHMORT" VARCHAR(25),'+
         '"20.45_SCHMORT" VARCHAR(25),"21.00_SCHMORT" VARCHAR(25),"21.15_SCHMORT" VARCHAR(25),'+
         '"21.30_SCHMORT" VARCHAR(25),"21.45_SCHMORT" VARCHAR(25),"22.00_SCHMORT" VARCHAR(25),'+
         '"22.15_SCHMORT" VARCHAR(25),"22.30_SCHMORT" VARCHAR(25),"22.45_SCHMORT" VARCHAR(25),'+
         '"23.00_SCHMORT" VARCHAR(25),"23.15_SCHMORT" VARCHAR(25),"23.30_SCHMORT" VARCHAR(25),'+
         '"23.45_SCHMORT" VARCHAR(25)'+

'"00.00_SYMPT" VARCHAR(10), "00.15_SYMPT" VARCHAR(25),'+
         '"00.30_SYMPT" VARCHAR(25),"00.45_SYMPT" VARCHAR(25),"01.00_SYMPT" VARCHAR(25),'+
         '"01.15_SYMPT" VARCHAR(25),"01.30_SYMPT" VARCHAR(25),"01.45_SYMPT" VARCHAR(25),'+
         '"02.00_SYMPT" VARCHAR(25),"02.15_SYMPT" VARCHAR(25),"02.30_SYMPT" VARCHAR(25),'+
         '"02.45_SYMPT" VARCHAR(25),"03.00_SYMPT" VARCHAR(25),"03.15_SYMPT" VARCHAR(25),'+
         '"03.30_SYMPT" VARCHAR(25),"03.45_SYMPT" VARCHAR(25),"04.00_SYMPT" VARCHAR(25),'+
         '"04.15_SYMPT" VARCHAR(25),"04.30_SYMPT" VARCHAR(25),"04.45_SYMPT" VARCHAR(25),'+
         '"05.00_SYMPT" VARCHAR(25),"05.15_SYMPT" VARCHAR(25),"05.30_SYMPT" VARCHAR(25),'+
         '"05.45_SYMPT" VARCHAR(25),"06.00_SYMPT" VARCHAR(25),"06.15_SYMPT" VARCHAR(25),'+
         '"06.30_SYMPT" VARCHAR(25),"06.45_SYMPT" VARCHAR(25),"07.00_SYMPT" VARCHAR(25),'+
         '"07.15_SYMPT" VARCHAR(25),"07.30_SYMPT" VARCHAR(25),"07.45_SYMPT" VARCHAR(25),'+
         '"08.00_SYMPT" VARCHAR(25),"08.15_SYMPT" VARCHAR(25),"08.30_SYMPT" VARCHAR(25),'+
         '"08.45_SYMPT" VARCHAR(25),"09.00_SYMPT" VARCHAR(25),"09.15_SYMPT" VARCHAR(25),'+
         '"09.30_SYMPT" VARCHAR(25),"09.45_SYMPT" VARCHAR(25),"10.00_SYMPT" VARCHAR(25),'+
         '"10.15_SYMPT" VARCHAR(25),"10.30_SYMPT" VARCHAR(25),"10.45_SYMPT" VARCHAR(25),'+
         '"11.00_SYMPT" VARCHAR(25),"11.15_SYMPT" VARCHAR(25),"11.30_SYMPT" VARCHAR(25),'+
         '"11.45_SYMPT" VARCHAR(25),"12.00_SYMPT" VARCHAR(25),"12.15_SYMPT" VARCHAR(25),'+
         '"12.30_SYMPT" VARCHAR(25),"12.45_SYMPT" VARCHAR(25),"13.00_SYMPT" VARCHAR(25),'+
         '"13.15_SYMPT" VARCHAR(25),"13.30_SYMPT" VARCHAR(25),"13.45_SYMPT" VARCHAR(25),'+
         '"14.00_SYMPT" VARCHAR(25),"14.15_SYMPT" VARCHAR(25),"14.30_SYMPT" VARCHAR(25),'+
         '"14.45_SYMPT" VARCHAR(25),"15.00_SYMPT" VARCHAR(25),"15.15_SYMPT" VARCHAR(25),'+
         '"15.30_SYMPT" VARCHAR(25),"15.45_SYMPT" VARCHAR(25),"16.00_SYMPT" VARCHAR(25),'+
         '"16.15_SYMPT" VARCHAR(25),"16.30_SYMPT" VARCHAR(25),"16.45_SYMPT" VARCHAR(25),'+
         '"17.00_SYMPT" VARCHAR(25),"17.15_SYMPT" VARCHAR(25),"17.30_SYMPT" VARCHAR(25),'+
         '"17.45_SYMPT" VARCHAR(25),"18.00_SYMPT" VARCHAR(25),"18.15_SYMPT" VARCHAR(25),'+
         '"18.30_SYMPT" VARCHAR(25),"18.45_SYMPT" VARCHAR(25),"19.00_SYMPT" VARCHAR(25),'+
         '"19.15_SYMPT" VARCHAR(25),"19.30_SYMPT" VARCHAR(25),"19.45_SYMPT" VARCHAR(25),'+
         '"20.00_SYMPT" VARCHAR(25),"20.15_SYMPT" VARCHAR(25),"20.30_SYMPT" VARCHAR(25),'+
         '"20.45_SYMPT" VARCHAR(25),"21.00_SYMPT" VARCHAR(25),"21.15_SYMPT" VARCHAR(25),'+
         '"21.30_SYMPT" VARCHAR(25),"21.45_SYMPT" VARCHAR(25),"22.00_SYMPT" VARCHAR(25),'+
         '"22.15_SYMPT" VARCHAR(25),"22.30_SYMPT" VARCHAR(25),"22.45_SYMPT" VARCHAR(25),'+
         '"23.00_SYMPT" VARCHAR(25),"23.15_SYMPT" VARCHAR(25),"23.30_SYMPT" VARCHAR(25),'+
         '"23.45_SYMPT" VARCHAR(25)'+

'"00.00_NOTITZ" VARCHAR(10), "00.15_NOTITZ" VARCHAR(25),'+
         '"00.30_NOTITZ" VARCHAR(25),"00.45_NOTITZ" VARCHAR(25),"01.00_NOTITZ" VARCHAR(25),'+
         '"01.15_NOTITZ" VARCHAR(25),"01.30_NOTITZ" VARCHAR(25),"01.45_NOTITZ" VARCHAR(25),'+
         '"02.00_NOTITZ" VARCHAR(25),"02.15_NOTITZ" VARCHAR(25),"02.30_NOTITZ" VARCHAR(25),'+
         '"02.45_NOTITZ" VARCHAR(25),"03.00_NOTITZ" VARCHAR(25),"03.15_NOTITZ" VARCHAR(25),'+
         '"03.30_NOTITZ" VARCHAR(25),"03.45_NOTITZ" VARCHAR(25),"04.00_NOTITZ" VARCHAR(25),'+
         '"04.15_NOTITZ" VARCHAR(25),"04.30_NOTITZ" VARCHAR(25),"04.45_NOTITZ" VARCHAR(25),'+
         '"05.00_NOTITZ" VARCHAR(25),"05.15_NOTITZ" VARCHAR(25),"05.30_NOTITZ" VARCHAR(25),'+
         '"05.45_NOTITZ" VARCHAR(25),"06.00_NOTITZ" VARCHAR(25),"06.15_NOTITZ" VARCHAR(25),'+
         '"06.30_NOTITZ" VARCHAR(25),"06.45_NOTITZ" VARCHAR(25),"07.00_NOTITZ" VARCHAR(25),'+
         '"07.15_NOTITZ" VARCHAR(25),"07.30_NOTITZ" VARCHAR(25),"07.45_NOTITZ" VARCHAR(25),'+
         '"08.00_NOTITZ" VARCHAR(25),"08.15_NOTITZ" VARCHAR(25),"08.30_NOTITZ" VARCHAR(25),'+
         '"08.45_NOTITZ" VARCHAR(25),"09.00_NOTITZ" VARCHAR(25),"09.15_NOTITZ" VARCHAR(25),'+
         '"09.30_NOTITZ" VARCHAR(25),"09.45_NOTITZ" VARCHAR(25),"10.00_NOTITZ" VARCHAR(25),'+
         '"10.15_NOTITZ" VARCHAR(25),"10.30_NOTITZ" VARCHAR(25),"10.45_NOTITZ" VARCHAR(25),'+
         '"11.00_NOTITZ" VARCHAR(25),"11.15_NOTITZ" VARCHAR(25),"11.30_NOTITZ" VARCHAR(25),'+
         '"11.45_NOTITZ" VARCHAR(25),"12.00_NOTITZ" VARCHAR(25),"12.15_NOTITZ" VARCHAR(25),'+
         '"12.30_NOTITZ" VARCHAR(25),"12.45_NOTITZ" VARCHAR(25),"13.00_NOTITZ" VARCHAR(25),'+
         '"13.15_NOTITZ" VARCHAR(25),"13.30_NOTITZ" VARCHAR(25),"13.45_NOTITZ" VARCHAR(25),'+
         '"14.00_NOTITZ" VARCHAR(25),"14.15_NOTITZ" VARCHAR(25),"14.30_NOTITZ" VARCHAR(25),'+
         '"14.45_NOTITZ" VARCHAR(25),"15.00_NOTITZ" VARCHAR(25),"15.15_NOTITZ" VARCHAR(25),'+
         '"15.30_NOTITZ" VARCHAR(25),"15.45_NOTITZ" VARCHAR(25),"16.00_NOTITZ" VARCHAR(25),'+
         '"16.15_NOTITZ" VARCHAR(25),"16.30_NOTITZ" VARCHAR(25),"16.45_NOTITZ" VARCHAR(25),'+
         '"17.00_NOTITZ" VARCHAR(25),"17.15_NOTITZ" VARCHAR(25),"17.30_NOTITZ" VARCHAR(25),'+
         '"17.45_NOTITZ" VARCHAR(25),"18.00_NOTITZ" VARCHAR(25),"18.15_NOTITZ" VARCHAR(25),'+
         '"18.30_NOTITZ" VARCHAR(25),"18.45_NOTITZ" VARCHAR(25),"19.00_NOTITZ" VARCHAR(25),'+
         '"19.15_NOTITZ" VARCHAR(25),"19.30_NOTITZ" VARCHAR(25),"19.45_NOTITZ" VARCHAR(25),'+
         '"20.00_NOTITZ" VARCHAR(25),"20.15_NOTITZ" VARCHAR(25),"20.30_NOTITZ" VARCHAR(25),'+
         '"20.45_NOTITZ" VARCHAR(25),"21.00_NOTITZ" VARCHAR(25),"21.15_NOTITZ" VARCHAR(25),'+
         '"21.30_NOTITZ" VARCHAR(25),"21.45_NOTITZ" VARCHAR(25),"22.00_NOTITZ" VARCHAR(25),'+
         '"22.15_NOTITZ" VARCHAR(25),"22.30_NOTITZ" VARCHAR(25),"22.45_NOTITZ" VARCHAR(25),'+
         '"23.00_NOTITZ" VARCHAR(25),"23.15_NOTITZ" VARCHAR(25),"23.30_NOTITZ" VARCHAR(25),'+
         '"23.45_NOTITZ" VARCHAR(25))';

  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblDateTime');
  end;

  SQL := 'CREATE TABLE IF NOT EXISTS tblJahr (ID INTEGER Primary KEY, Year Date)';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblJahr');
  end;

  SQL := 'CREATE TABLE IF NOT EXISTS tblMonth (ID INTEGER Primary KEY, Month Date)';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblMonth');
  end;

 SQL := 'CREATE TABLE IF NOT EXISTS tblAusloeser ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"AUSLOESER_SHORT" VARCHAR(10), "AUSLOESER_LONG" VARCHAR(25))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblAusloeser');
  end;





SQL := 'CREATE TABLE IF NOT EXISTS tblSchmerz-Ort ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"SCHMERTZ_ORT_S" VARCHAR(10), "SCHMERTZ_ORT_L" VARCHAR(25))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblSchmerz-Ort');
  end;


SQL := 'CREATE TABLE IF NOT EXISTS tblSymptom ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"SYMPTOM_SHORT" VARCHAR(10), "SYMPTOM_LONG" VARCHAR(25))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblSymptom');
  end;



SQL := 'CREATE TABLE IF NOT EXISTS tblNotizen ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"NOTITZ_SHORT" VARCHAR(25), "NOTITZ_LONG" VARCHAR(100))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblNotizen');
  end;

  //{Löscht die Tabelle Jahr (fals vorhanden)}
  SQL := 'DROP TABLE IF EXISTS tblJahr';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot drop tblJahr');
  end;

  //{Erstellt Tabelle Jahr und für diverse Jahre als Einträge hinzu}
  SQL := 'CREATE TABLE IF NOT EXISTS tblJahr ( ID INTEGER Primary KEY, Jahr VARCHAR(6))';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblJahr');
  end;

  Con1.Transaction.StartTransaction;
  try
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2010")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2011")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2012")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2013")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2014")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2015")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2016")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2017")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2018")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2019")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2020")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "2009")';
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot insert values in tblJahr');
  end;

  //{Löscht die Tabelle Monat}
  SQL := 'DROP TABLE IF EXISTS tblMonth';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot drop tblMonth');
  end;

  //{Erstellt Tabelle Monat und für diverse Monate als Einträge hinzu}
  SQL := 'CREATE TABLE IF NOT EXISTS tblMonth (ID INTEGER Primary KEY, Month VARCHAR(25))';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblMonth');
  end;

  Con1.Transaction.StartTransaction;
  try
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "Januar")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "Februar")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "März")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "April")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "Mai")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "Juni")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "Juli")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "August")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "September")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "Oktober")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "November")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblMonth VALUES (NULL, "Dezember")';
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot insert values in tblMonth');
  end;
   //{Löscht die Tabelle Jahr (fals vorhanden)}
  SQL := 'DROP TABLE IF EXISTS tblSchmerz-Ort';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot drop tblSchmerz-Ort');
  end;

  //{Erstellt Tabelle Jahr und für diverse Jahre als Einträge hinzu}
SQL := 'CREATE TABLE IF NOT EXISTS tblSchmerz-Ort ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"SCHMERTZ_ORT_S" VARCHAR(10), "SCHMERTZ_ORT_L" VARCHAR(25))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblSchmerz-Ort');
  end;

  Con1.Transaction.StartTransaction;
  try
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "right back in ear")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "left back in ear")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "back site of head")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "back in left eye")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "back in right eye")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "completely of Head")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "left site of Head")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "right site of Head")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "front of Head")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "left site of front Head")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "right site of front Head")';
    Con1.ExecuteDirect(SQL);

    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot insert values in tblSchmerz-Ort');
  end;
  //{Löscht die Tabelle Jahr (fals vorhanden)}
  SQL := 'DROP TABLE IF EXISTS tblAusloeser';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot drop tblAusloeser');
  end;

  //{Erstellt Tabelle Jahr und für diverse Jahre als Einträge hinzu}
 SQL := 'CREATE TABLE IF NOT EXISTS tblAusloeser ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"AUSLOESER_SHORT" VARCHAR(10), "AUSLOESER_LONG" VARCHAR(25))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblAusloeser');
  end;

  Con1.Transaction.StartTransaction;
  try
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Medications")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Skipping meals / fasting")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food Beverages")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food Bread & Grains")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food Dairy products")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food fruits")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food meat, fish, pouletry")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food Misscellaneous")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food Soupe")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food sweets")';
    Con1.ExecuteDirect(SQL);

    SQL := 'INSERT INTO tblJahr VALUES (NULL, "food vegetables")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Enviromental Other")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Enviromental Weather")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Hormonal Changes")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Physical Becoming tired")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Sleep Changes")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Stress")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Stress letdown")';
    Con1.ExecuteDirect(SQL);

    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot insert values in tblAusloeser');
  end;
  //{Löscht die Tabelle Jahr (fals vorhanden)}
  SQL := 'DROP TABLE IF EXISTS tblSchmerz-Staerke';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot drop tblSchmerz-Staerke');
  end;

  //{Erstellt Tabelle Jahr und für diverse Jahre als Einträge hinzu}
SQL := 'CREATE TABLE IF NOT EXISTS tblSchmerz-Staerke ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"SCHMERZSTAERKE_SHORT" VARCHAR(10), "SCHMERZSTAERKE_LONG" VARCHAR(25))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblSchmerz-Staerke');
  end;

  Con1.Transaction.StartTransaction;
  try
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Light")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "very mild")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Discomforting")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Distressing")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "very Distressing")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "intense")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "very Intence")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Utterly Horrible")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Unbearble")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Unimaginable")';
    Con1.ExecuteDirect(SQL);

    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot insert values in tblSchmerz-Staerke');
  end;
  //{Löscht die Tabelle Jahr (fals vorhanden)}
  SQL := 'DROP TABLE IF EXISTS tblSymptom';
  Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot drop tblSymptom');
  end;

  //{Erstellt Tabelle Jahr und für diverse Jahre als Einträge hinzu}
SQL := 'CREATE TABLE IF NOT EXISTS tblSymptom ' +
         '(ID INTEGER PRIMARY KEY,Jahr Date, Monat Date, aktDatum Date, '+
'"SYMPTOM_SHORT" VARCHAR(10), "SYMPTOM_LONG" VARCHAR(25), , "SYMPTOM_TRUE_FALSE" VARCHAR(25))';
Con1.Transaction.StartTransaction;
  try
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot create tblSymptom');
  end;

  Con1.Transaction.StartTransaction;
  try
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Light sensitive")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Stiff of painfull neck")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "running Nose")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Sound sensitive")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "smell sensitiv")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Eye tearing")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Tingling")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Eyelid swelling")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Face dropping")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "nausea")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "visual Changes")';
    Con1.ExecuteDirect(SQL);
    SQL := 'INSERT INTO tblJahr VALUES (NULL, "Vomiting")';
    Con1.ExecuteDirect(SQL);
    Con1.Transaction.Commit;
  except
    Con1.Transaction.Rollback;
    DebugLn('Error: Cannot insert values in tblSymptom');
  end;
end;

function TDM1.DeleteDB: Boolean;
begin
  Result := false;
  if Con1.Connected then
  begin
    DebugLn('Error: Already connected to the DB');
    exit;
  end;
  if not FileExists(Con1.DatabaseName) then
  begin
    DebugLn('Error: DB does not exists');
    exit;
  end;
  Con1.DropDB;
  Result := true;
  DebugLn('DeleteDB finished');
end;


end.

